# -*- coding: utf-8 -*-
import numpy as np

def selectColors(n_colors,**kwargs):
  """ pick colors that are maximally perceptually distinct.
    
  Syntax:
  
    colors = selectColors(n_colors)
    colors = selectColors(n_colors,backgrounds=bg)
  
  Specify the number of colors you want as a scalar, n_colors. This will
  generate an n_colors-by-3 numpy array, each row representing an RGB
  color triple.
  
  The backgrounds option allows you to specify the background colors, 
  to make sure that your colors are also distinguishable from the colors
  specify in the n-by-3 numpy array each row representing an RGB color triple.
  Default value is np.array([[1,1,1],[0,0,0],[0.8,0.8,0.8],[1,0,1]]
  
  This function was inspired by the Matlab function select_colors 
  (or distinguishable_colors) from Timothy E. Holy.
  
  Copyright 2017 by F. Cuvelier
  """
  bg=kwargs.get('backgrounds', np.array([[1,1,1],[0,0,0],[0.8,0.8,0.8],[1,0,1]]) )
  func=kwargs.get('func', lambda x: RGB2LAB(x) )
  n_grid = 30
  h=1/(n_grid-1.);F=1+h/2.
  B,G,R = np.mgrid[0:F:h,0:F:h,0:F:h]
  N=(n_grid)**3
  rgb=np.zeros((N,3))
  rgb[:,0]=R.reshape((N,))
  rgb[:,1]=G.reshape((N,))
  rgb[:,2]=B.reshape((N,))
  lab=func(rgb)
  bglab = func(bg)

  mindist2 = np.ones((N,))*np.inf
  for i in range(bglab.shape[0]-1):
    dX=lab-np.ones((N,1))*bglab[i]  # displacement all colors from bg
    dist2 = np.sum(dX**2,1)  # square distance
    mindist2 = np.minimum(dist2,mindist2)
    
  colors=np.zeros((n_colors,3))
  lastlab = bglab[-1]
  for i in range(n_colors):
    dX = lab-np.ones((N,1))*lastlab
    dist2 = np.sum(dX**2,1)  # square distance
    mindist2 = np.minimum(dist2,mindist2)
    I=np.where(mindist2==mindist2.max())[0][0]
    colors[i]=rgb[I]
    lastlab=lab[I]
  return colors

def RGB2XYZ(rgb):
  N=rgb.shape[0]
  RGB=np.zeros(rgb.shape)
  RGB[:,0]=rgb[:,0]  # R from 0 to 1
  RGB[:,1]=rgb[:,1]  # G from 0 to 1
  RGB[:,2]=rgb[:,2]  # B from 0 to 1

  for i in range(3):
    I=np.where(RGB[:,i] > 0.0404482362771076)[0]
    RGB[I,i] = ( ( RGB[I,i] + 0.055 ) / 1.055 )** 2.4;
    I=np.setdiff1d(range(N),I);
    RGB[I,i] = RGB[I,i] / 12.92;

    # Observer. = 2°, Illuminant = D65+-
    #  Y = var_R * 0.2126 + var_G * 0.7152 + var_B * 0.0722;
    #  Z = var_R * 0.0193 + var_G * 0.1192 + var_B * 0.9505;
  A=np.array([[0.4123955889674142161,0.3575834307637148171,0.1804926473817015735],
              [0.2125862307855955516,0.7151703037034108499,0.07220049864333622685],
              [0.01929721549174694484,0.1191838645808485318,0.9504971251315797660]]).T
  return np.dot(RGB,A)

def XYZ2LAB(XYZ):
  WHITEPOINT_X=0.950456
  WHITEPOINT_Y=1.0
  WHITEPOINT_Z=1.088754
  X=XYZ[:,0]/WHITEPOINT_X
  Y=XYZ[:,1]/WHITEPOINT_Y
  Z=XYZ[:,2]/WHITEPOINT_Z

  N=XYZ.shape[0]
  LAB=np.zeros((N,3))

  X = LABF(X)
  Y = LABF(Y)
  Z = LABF(Z)
  LAB[:,0] = 116*Y - 16
  LAB[:,1] = 500*(X - Y)
  LAB[:,2] = 200*(Y - Z)
  return LAB

def LABF(t):
  N=len(t);z=0*t;
  I=np.where(t >= 8.85645167903563082e-3)[0]
  z[I]=t[I]**(0.333333333333333)
  I=np.setdiff1d(range(N),I)
  z[I]=(841.0/108.0)*(t[I]) + (4.0/29.0)
  return z

def RGB2LAB(RGB):
  XYZ=RGB2XYZ(RGB)
  return XYZ2LAB(XYZ)

def get_themes():
  return ['svg','X11']

    
def check_color(color):
  if color is None:
    return None
  if isinstance(color,tuple):
    return color
  if isinstance(color,str):
    rgb=str2rgb(color) 
    if rgb is not None:
      return tuple(rgb)
  if isinstance(color,list) or isinstance(color,np.ndarray):
    return tuple(color)
  print("Unknow color :"+str(color) )
  return (0,0,0)

def str2rgb(name,**kwargs):
  """ get RGB color triple from X11 or svg colors name.
    
  Syntax:
  
    rgb = str2rgb(name)
    
  Returns the RGB color triple associated with a X11 color name or
  a svg color name.
  
  All the X11 and svg color names can be obtain by
    
    from fc_tools.colors import X11,svg
    X11().keys()
    svg().keys()
    
  Copyright 2017 by F. Cuvelier
  """
  theme=kwargs.get('theme', None )
  name=name.lower()
  if theme is None:
    theme=get_themes()
    for t in theme:
      rgb=str2rgb_theme(t,name)
      if rgb is not None:
        return rgb
  else:
    themes=get_themes()
    assert(theme in themes)
    rgb=str2rgb_theme(theme,name)
    if rgb is not None:
      return rgb
  print('Color %s not found!'%name)
  return None

def str2rgb_theme(theme,name):
  rgb=None
  if theme in get_themes():
    colordict=eval(theme+"()")
    if name in colordict:
      rgb=colordict[name]
  return rgb

def X11():
  name=[
  'AntiqueWhite1',
  'AntiqueWhite2',
  'AntiqueWhite3',
  'AntiqueWhite4',
  'Aquamarine1',
  'Aquamarine2',
  'Aquamarine3',
  'Aquamarine4',
  'Azure1',
  'Azure2',
  'Azure3',
  'Azure4',
  'Bisque1',
  'Bisque2',
  'Bisque3',
  'Bisque4',
  'Blue1',
  'Blue2',
  'Blue3',
  'Blue4',
  'Brown1',
  'Brown2',
  'Brown3',
  'Brown4',
  'Burlywood1',
  'Burlywood2',
  'Burlywood3',
  'Burlywood4',
  'CadetBlue1',
  'CadetBlue2',
  'CadetBlue3',
  'CadetBlue4',
  'Chartreuse1',
  'Chartreuse2',
  'Chartreuse3',
  'Chartreuse4',
  'Chocolate1',
  'Chocolate2',
  'Chocolate3',
  'Chocolate4',
  'Coral1',
  'Coral2',
  'Coral3',
  'Coral4',
  'Cornsilk1',
  'Cornsilk2',
  'Cornsilk3',
  'Cornsilk4',
  'Cyan1',
  'Cyan2',
  'Cyan3',
  'Cyan4',
  'DarkGoldenrod1',
  'DarkGoldenrod2',
  'DarkGoldenrod3',
  'DarkGoldenrod4',
  'DarkOliveGreen1',
  'DarkOliveGreen2',
  'DarkOliveGreen3',
  'DarkOliveGreen4',
  'DarkOrange1',
  'DarkOrange2',
  'DarkOrange3',
  'DarkOrange4',
  'DarkOrchid1',
  'DarkOrchid2',
  'DarkOrchid3',
  'DarkOrchid4',
  'DarkSeaGreen1',
  'DarkSeaGreen2',
  'DarkSeaGreen3',
  'DarkSeaGreen4',
  'DarkSlateGray1',
  'DarkSlateGray2',
  'DarkSlateGray3',
  'DarkSlateGray4',
  'DeepPink1',
  'DeepPink2',
  'DeepPink3',
  'DeepPink4',
  'DeepSkyBlue1',
  'DeepSkyBlue2',
  'DeepSkyBlue3',
  'DeepSkyBlue4',
  'DodgerBlue1',
  'DodgerBlue2',
  'DodgerBlue3',
  'DodgerBlue4',
  'Firebrick1',
  'Firebrick2',
  'Firebrick3',
  'Firebrick4',
  'Gold1',
  'Gold2',
  'Gold3',
  'Gold4',
  'Goldenrod1',
  'Goldenrod2',
  'Goldenrod3',
  'Goldenrod4',
  'Green1',
  'Green2',
  'Green3',
  'Green4',
  'Honeydew1',
  'Honeydew2',
  'Honeydew3',
  'Honeydew4',
  'HotPink1',
  'HotPink2',
  'HotPink3',
  'HotPink4',
  'IndianRed1',
  'IndianRed2',
  'IndianRed3',
  'IndianRed4',
  'Ivory1',
  'Ivory2',
  'Ivory3',
  'Ivory4',
  'Khaki1',
  'Khaki2',
  'Khaki3',
  'Khaki4',
  'LavenderBlush1',
  'LavenderBlush2',
  'LavenderBlush3',
  'LavenderBlush4',
  'LemonChiffon1',
  'LemonChiffon2',
  'LemonChiffon3',
  'LemonChiffon4',
  'LightBlue1',
  'LightBlue2',
  'LightBlue3',
  'LightBlue4',
  'LightCyan1',
  'LightCyan2',
  'LightCyan3',
  'LightCyan4',
  'LightGoldenrod1',
  'LightGoldenrod2',
  'LightGoldenrod3',
  'LightGoldenrod4',
  'LightPink1',
  'LightPink2',
  'LightPink3',
  'LightPink4',
  'LightSalmon1',
  'LightSalmon2',
  'LightSalmon3',
  'LightSalmon4',
  'LightSkyBlue1',
  'LightSkyBlue2',
  'LightSkyBlue3',
  'LightSkyBlue4',
  'LightSteelBlue1',
  'LightSteelBlue2',
  'LightSteelBlue3',
  'LightSteelBlue4',
  'LightYellow1',
  'LightYellow2',
  'LightYellow3',
  'LightYellow4',
  'Magenta1',
  'Magenta2',
  'Magenta3',
  'Magenta4',
  'Maroon1',
  'Maroon2',
  'Maroon3',
  'Maroon4',
  'MediumOrchid1',
  'MediumOrchid2',
  'MediumOrchid3',
  'MediumOrchid4',
  'MediumPurple1',
  'MediumPurple2',
  'MediumPurple3',
  'MediumPurple4',
  'MistyRose1',
  'MistyRose2',
  'MistyRose3',
  'MistyRose4',
  'NavajoWhite1',
  'NavajoWhite2',
  'NavajoWhite3',
  'NavajoWhite4',
  'OliveDrab1',
  'OliveDrab2',
  'OliveDrab3',
  'OliveDrab4',
  'Orange1',
  'Orange2',
  'Orange3',
  'Orange4',
  'OrangeRed1',
  'OrangeRed2',
  'OrangeRed3',
  'OrangeRed4',
  'Orchid1',
  'Orchid2',
  'Orchid3',
  'Orchid4',
  'PaleGreen1',
  'PaleGreen2',
  'PaleGreen3',
  'PaleGreen4',
  'PaleTurquoise1',
  'PaleTurquoise2',
  'PaleTurquoise3',
  'PaleTurquoise4',
  'PaleVioletRed1',
  'PaleVioletRed2',
  'PaleVioletRed3',
  'PaleVioletRed4',
  'PeachPuff1',
  'PeachPuff2',
  'PeachPuff3',
  'PeachPuff4',
  'Pink1',
  'Pink2',
  'Pink3',
  'Pink4',
  'Plum1',
  'Plum2',
  'Plum3',
  'Plum4',
  'Purple1',
  'Purple2',
  'Purple3',
  'Purple4',
  'Red1',
  'Red2',
  'Red3',
  'Red4',
  'RosyBrown1',
  'RosyBrown2',
  'RosyBrown3',
  'RosyBrown4',
  'RoyalBlue1',
  'RoyalBlue2',
  'RoyalBlue3',
  'RoyalBlue4',
  'Salmon1',
  'Salmon2',
  'Salmon3',
  'Salmon4',
  'SeaGreen1',
  'SeaGreen2',
  'SeaGreen3',
  'SeaGreen4',
  'Seashell1',
  'Seashell2',
  'Seashell3',
  'Seashell4',
  'Sienna1',
  'Sienna2',
  'Sienna3',
  'Sienna4',
  'SkyBlue1',
  'SkyBlue2',
  'SkyBlue3',
  'SkyBlue4',
  'SlateBlue1',
  'SlateBlue2',
  'SlateBlue3',
  'SlateBlue4',
  'SlateGray1',
  'SlateGray2',
  'SlateGray3',
  'SlateGray4',
  'Snow1',
  'Snow2',
  'Snow3',
  'Snow4',
  'SpringGreen1',
  'SpringGreen2',
  'SpringGreen3',
  'SpringGreen4',
  'SteelBlue1',
  'SteelBlue2',
  'SteelBlue3',
  'SteelBlue4',
  'Tan1',
  'Tan2',
  'Tan3',
  'Tan4',
  'Thistle1',
  'Thistle2',
  'Thistle3',
  'Thistle4',
  'Tomato1',
  'Tomato2',
  'Tomato3',
  'Tomato4',
  'Turquoise1',
  'Turquoise2',
  'Turquoise3',
  'Turquoise4',
  'VioletRed1',
  'VioletRed2',
  'VioletRed3',
  'VioletRed4',
  'Wheat1',
  'Wheat2',
  'Wheat3',
  'Wheat4',
  'Yellow1',
  'Yellow2',
  'Yellow3',
  'Yellow4',
  'Gray0',
  'Green0',
  'Grey0',
  'Maroon0',
  'Purple0']
  rgb=[
  [1.000000,0.936000,0.860000],
  [0.932000,0.875000,0.800000],
  [0.804000,0.752000,0.690000],
  [0.545000,0.512000,0.470000],
  [0.498000,1.000000,0.830000],
  [0.464000,0.932000,0.776000],
  [0.400000,0.804000,0.668000],
  [0.270000,0.545000,0.455000],
  [0.940000,1.000000,1.000000],
  [0.880000,0.932000,0.932000],
  [0.756000,0.804000,0.804000],
  [0.512000,0.545000,0.545000],
  [1.000000,0.894000,0.770000],
  [0.932000,0.835000,0.716000],
  [0.804000,0.716000,0.620000],
  [0.545000,0.490000,0.420000],
  [0.000000,0.000000,1.000000],
  [0.000000,0.000000,0.932000],
  [0.000000,0.000000,0.804000],
  [0.000000,0.000000,0.545000],
  [1.000000,0.250000,0.250000],
  [0.932000,0.230000,0.230000],
  [0.804000,0.200000,0.200000],
  [0.545000,0.136000,0.136000],
  [1.000000,0.828000,0.608000],
  [0.932000,0.772000,0.570000],
  [0.804000,0.668000,0.490000],
  [0.545000,0.450000,0.332000],
  [0.596000,0.960000,1.000000],
  [0.556000,0.898000,0.932000],
  [0.480000,0.772000,0.804000],
  [0.325000,0.525000,0.545000],
  [0.498000,1.000000,0.000000],
  [0.464000,0.932000,0.000000],
  [0.400000,0.804000,0.000000],
  [0.270000,0.545000,0.000000],
  [1.000000,0.498000,0.140000],
  [0.932000,0.464000,0.130000],
  [0.804000,0.400000,0.112000],
  [0.545000,0.270000,0.075000],
  [1.000000,0.448000,0.336000],
  [0.932000,0.415000,0.312000],
  [0.804000,0.356000,0.270000],
  [0.545000,0.244000,0.185000],
  [1.000000,0.972000,0.864000],
  [0.932000,0.910000,0.804000],
  [0.804000,0.785000,0.694000],
  [0.545000,0.532000,0.470000],
  [0.000000,1.000000,1.000000],
  [0.000000,0.932000,0.932000],
  [0.000000,0.804000,0.804000],
  [0.000000,0.545000,0.545000],
  [1.000000,0.725000,0.060000],
  [0.932000,0.680000,0.055000],
  [0.804000,0.585000,0.048000],
  [0.545000,0.396000,0.030000],
  [0.792000,1.000000,0.440000],
  [0.736000,0.932000,0.408000],
  [0.635000,0.804000,0.352000],
  [0.430000,0.545000,0.240000],
  [1.000000,0.498000,0.000000],
  [0.932000,0.464000,0.000000],
  [0.804000,0.400000,0.000000],
  [0.545000,0.270000,0.000000],
  [0.750000,0.244000,1.000000],
  [0.698000,0.228000,0.932000],
  [0.604000,0.196000,0.804000],
  [0.408000,0.132000,0.545000],
  [0.756000,1.000000,0.756000],
  [0.705000,0.932000,0.705000],
  [0.608000,0.804000,0.608000],
  [0.410000,0.545000,0.410000],
  [0.592000,1.000000,1.000000],
  [0.552000,0.932000,0.932000],
  [0.475000,0.804000,0.804000],
  [0.320000,0.545000,0.545000],
  [1.000000,0.080000,0.576000],
  [0.932000,0.070000,0.536000],
  [0.804000,0.064000,0.464000],
  [0.545000,0.040000,0.312000],
  [0.000000,0.750000,1.000000],
  [0.000000,0.698000,0.932000],
  [0.000000,0.604000,0.804000],
  [0.000000,0.408000,0.545000],
  [0.116000,0.565000,1.000000],
  [0.110000,0.525000,0.932000],
  [0.094000,0.455000,0.804000],
  [0.064000,0.305000,0.545000],
  [1.000000,0.190000,0.190000],
  [0.932000,0.172000,0.172000],
  [0.804000,0.150000,0.150000],
  [0.545000,0.100000,0.100000],
  [1.000000,0.844000,0.000000],
  [0.932000,0.790000,0.000000],
  [0.804000,0.680000,0.000000],
  [0.545000,0.460000,0.000000],
  [1.000000,0.756000,0.145000],
  [0.932000,0.705000,0.132000],
  [0.804000,0.608000,0.112000],
  [0.545000,0.410000,0.080000],
  [0.000000,1.000000,0.000000],
  [0.000000,0.932000,0.000000],
  [0.000000,0.804000,0.000000],
  [0.000000,0.545000,0.000000],
  [0.940000,1.000000,0.940000],
  [0.880000,0.932000,0.880000],
  [0.756000,0.804000,0.756000],
  [0.512000,0.545000,0.512000],
  [1.000000,0.430000,0.705000],
  [0.932000,0.415000,0.655000],
  [0.804000,0.376000,0.565000],
  [0.545000,0.228000,0.385000],
  [1.000000,0.415000,0.415000],
  [0.932000,0.390000,0.390000],
  [0.804000,0.332000,0.332000],
  [0.545000,0.228000,0.228000],
  [1.000000,1.000000,0.940000],
  [0.932000,0.932000,0.880000],
  [0.804000,0.804000,0.756000],
  [0.545000,0.545000,0.512000],
  [1.000000,0.965000,0.560000],
  [0.932000,0.900000,0.520000],
  [0.804000,0.776000,0.450000],
  [0.545000,0.525000,0.305000],
  [1.000000,0.940000,0.960000],
  [0.932000,0.880000,0.898000],
  [0.804000,0.756000,0.772000],
  [0.545000,0.512000,0.525000],
  [1.000000,0.980000,0.804000],
  [0.932000,0.912000,0.750000],
  [0.804000,0.790000,0.648000],
  [0.545000,0.536000,0.440000],
  [0.750000,0.936000,1.000000],
  [0.698000,0.875000,0.932000],
  [0.604000,0.752000,0.804000],
  [0.408000,0.512000,0.545000],
  [0.880000,1.000000,1.000000],
  [0.820000,0.932000,0.932000],
  [0.705000,0.804000,0.804000],
  [0.480000,0.545000,0.545000],
  [1.000000,0.925000,0.545000],
  [0.932000,0.864000,0.510000],
  [0.804000,0.745000,0.440000],
  [0.545000,0.505000,0.298000],
  [1.000000,0.684000,0.725000],
  [0.932000,0.635000,0.680000],
  [0.804000,0.550000,0.585000],
  [0.545000,0.372000,0.396000],
  [1.000000,0.628000,0.480000],
  [0.932000,0.585000,0.448000],
  [0.804000,0.505000,0.385000],
  [0.545000,0.340000,0.260000],
  [0.690000,0.888000,1.000000],
  [0.644000,0.828000,0.932000],
  [0.552000,0.712000,0.804000],
  [0.376000,0.484000,0.545000],
  [0.792000,0.884000,1.000000],
  [0.736000,0.824000,0.932000],
  [0.635000,0.710000,0.804000],
  [0.430000,0.484000,0.545000],
  [1.000000,1.000000,0.880000],
  [0.932000,0.932000,0.820000],
  [0.804000,0.804000,0.705000],
  [0.545000,0.545000,0.480000],
  [1.000000,0.000000,1.000000],
  [0.932000,0.000000,0.932000],
  [0.804000,0.000000,0.804000],
  [0.545000,0.000000,0.545000],
  [1.000000,0.204000,0.700000],
  [0.932000,0.190000,0.655000],
  [0.804000,0.160000,0.565000],
  [0.545000,0.110000,0.385000],
  [0.880000,0.400000,1.000000],
  [0.820000,0.372000,0.932000],
  [0.705000,0.320000,0.804000],
  [0.480000,0.215000,0.545000],
  [0.670000,0.510000,1.000000],
  [0.624000,0.475000,0.932000],
  [0.536000,0.408000,0.804000],
  [0.365000,0.280000,0.545000],
  [1.000000,0.894000,0.884000],
  [0.932000,0.835000,0.824000],
  [0.804000,0.716000,0.710000],
  [0.545000,0.490000,0.484000],
  [1.000000,0.870000,0.680000],
  [0.932000,0.810000,0.630000],
  [0.804000,0.700000,0.545000],
  [0.545000,0.475000,0.370000],
  [0.752000,1.000000,0.244000],
  [0.700000,0.932000,0.228000],
  [0.604000,0.804000,0.196000],
  [0.410000,0.545000,0.132000],
  [1.000000,0.648000,0.000000],
  [0.932000,0.604000,0.000000],
  [0.804000,0.520000,0.000000],
  [0.545000,0.352000,0.000000],
  [1.000000,0.270000,0.000000],
  [0.932000,0.250000,0.000000],
  [0.804000,0.215000,0.000000],
  [0.545000,0.145000,0.000000],
  [1.000000,0.512000,0.980000],
  [0.932000,0.480000,0.912000],
  [0.804000,0.410000,0.790000],
  [0.545000,0.280000,0.536000],
  [0.604000,1.000000,0.604000],
  [0.565000,0.932000,0.565000],
  [0.488000,0.804000,0.488000],
  [0.330000,0.545000,0.330000],
  [0.732000,1.000000,1.000000],
  [0.684000,0.932000,0.932000],
  [0.590000,0.804000,0.804000],
  [0.400000,0.545000,0.545000],
  [1.000000,0.510000,0.670000],
  [0.932000,0.475000,0.624000],
  [0.804000,0.408000,0.536000],
  [0.545000,0.280000,0.365000],
  [1.000000,0.855000,0.725000],
  [0.932000,0.796000,0.680000],
  [0.804000,0.688000,0.585000],
  [0.545000,0.468000,0.396000],
  [1.000000,0.710000,0.772000],
  [0.932000,0.664000,0.720000],
  [0.804000,0.570000,0.620000],
  [0.545000,0.390000,0.424000],
  [1.000000,0.732000,1.000000],
  [0.932000,0.684000,0.932000],
  [0.804000,0.590000,0.804000],
  [0.545000,0.400000,0.545000],
  [0.608000,0.190000,1.000000],
  [0.570000,0.172000,0.932000],
  [0.490000,0.150000,0.804000],
  [0.332000,0.100000,0.545000],
  [1.000000,0.000000,0.000000],
  [0.932000,0.000000,0.000000],
  [0.804000,0.000000,0.000000],
  [0.545000,0.000000,0.000000],
  [1.000000,0.756000,0.756000],
  [0.932000,0.705000,0.705000],
  [0.804000,0.608000,0.608000],
  [0.545000,0.410000,0.410000],
  [0.284000,0.464000,1.000000],
  [0.264000,0.430000,0.932000],
  [0.228000,0.372000,0.804000],
  [0.152000,0.250000,0.545000],
  [1.000000,0.550000,0.410000],
  [0.932000,0.510000,0.385000],
  [0.804000,0.440000,0.330000],
  [0.545000,0.298000,0.224000],
  [0.330000,1.000000,0.624000],
  [0.305000,0.932000,0.580000],
  [0.264000,0.804000,0.500000],
  [0.180000,0.545000,0.340000],
  [1.000000,0.960000,0.932000],
  [0.932000,0.898000,0.870000],
  [0.804000,0.772000,0.750000],
  [0.545000,0.525000,0.510000],
  [1.000000,0.510000,0.280000],
  [0.932000,0.475000,0.260000],
  [0.804000,0.408000,0.224000],
  [0.545000,0.280000,0.150000],
  [0.530000,0.808000,1.000000],
  [0.494000,0.752000,0.932000],
  [0.424000,0.650000,0.804000],
  [0.290000,0.440000,0.545000],
  [0.512000,0.435000,1.000000],
  [0.480000,0.404000,0.932000],
  [0.410000,0.350000,0.804000],
  [0.280000,0.235000,0.545000],
  [0.776000,0.888000,1.000000],
  [0.725000,0.828000,0.932000],
  [0.624000,0.712000,0.804000],
  [0.424000,0.484000,0.545000],
  [1.000000,0.980000,0.980000],
  [0.932000,0.912000,0.912000],
  [0.804000,0.790000,0.790000],
  [0.545000,0.536000,0.536000],
  [0.000000,1.000000,0.498000],
  [0.000000,0.932000,0.464000],
  [0.000000,0.804000,0.400000],
  [0.000000,0.545000,0.270000],
  [0.390000,0.720000,1.000000],
  [0.360000,0.675000,0.932000],
  [0.310000,0.580000,0.804000],
  [0.210000,0.392000,0.545000],
  [1.000000,0.648000,0.310000],
  [0.932000,0.604000,0.288000],
  [0.804000,0.520000,0.248000],
  [0.545000,0.352000,0.170000],
  [1.000000,0.884000,1.000000],
  [0.932000,0.824000,0.932000],
  [0.804000,0.710000,0.804000],
  [0.545000,0.484000,0.545000],
  [1.000000,0.390000,0.280000],
  [0.932000,0.360000,0.260000],
  [0.804000,0.310000,0.224000],
  [0.545000,0.210000,0.150000],
  [0.000000,0.960000,1.000000],
  [0.000000,0.898000,0.932000],
  [0.000000,0.772000,0.804000],
  [0.000000,0.525000,0.545000],
  [1.000000,0.244000,0.590000],
  [0.932000,0.228000,0.550000],
  [0.804000,0.196000,0.470000],
  [0.545000,0.132000,0.320000],
  [1.000000,0.905000,0.730000],
  [0.932000,0.848000,0.684000],
  [0.804000,0.730000,0.590000],
  [0.545000,0.494000,0.400000],
  [1.000000,1.000000,0.000000],
  [0.932000,0.932000,0.000000],
  [0.804000,0.804000,0.000000],
  [0.545000,0.545000,0.000000],
  [0.745000,0.745000,0.745000],
  [0.000000,1.000000,0.000000],
  [0.745000,0.745000,0.745000],
  [0.690000,0.190000,0.376000],
  [0.628000,0.125000,0.940000]]
  name=[x.lower() for x in name]
  return dict(zip(name,rgb))

def svg():
  name=[
  'Aqua',
  'Aquamarine',
  'Azure',
  'Beige',
  'Bisque',
  'Black',
  'BlanchedAlmond',
  'Blue',
  'BlueViolet',
  'Brown',
  'BurlyWood',
  'CadetBlue',
  'Chartreuse',
  'Chocolate',
  'Coral',
  'CornflowerBlue',
  'Cornsilk',
  'Crimson',
  'Cyan',
  'DarkBlue',
  'DarkCyan',
  'DarkGoldenrod',
  'DarkGray',
  'DarkGreen',
  'DarkGrey',
  'DarkKhaki',
  'DarkMagenta',
  'DarkOliveGreen',
  'DarkOrange',
  'DarkOrchid',
  'DarkRed',
  'DarkSalmon',
  'DarkSeaGreen',
  'DarkSlateBlue',
  'DarkSlateGray',
  'DarkSlateGrey',
  'DarkTurquoise',
  'DarkViolet',
  'DeepPink',
  'DeepSkyBlue',
  'DimGray',
  'DimGrey',
  'DodgerBlue',
  'FireBrick',
  'FloralWhite',
  'ForestGreen',
  'Fuchsia',
  'Gainsboro',
  'GhostWhite',
  'Gold',
  'Goldenrod',
  'Gray',
  'Green',
  'GreenYellow',
  'Grey',
  'Honeydew',
  'HotPink',
  'IndianRed',
  'Indigo',
  'Ivory',
  'Khaki',
  'Lavender',
  'LavenderBlush',
  'LawnGreen',
  'LemonChiffon',
  'LightBlue',
  'LightCoral',
  'LightCyan',
  'LightGoldenrod',
  'LightGoldenrodYellow',
  'LightGray',
  'LightGreen',
  'LightGrey',
  'LightPink',
  'LightSalmon',
  'LightSeaGreen',
  'LightSkyBlue',
  'LightSlateBlue',
  'LightSlateGray',
  'LightSlateGrey',
  'LightSteelBlue',
  'LightYellow',
  'Lime',
  'LimeGreen',
  'Linen',
  'Magenta',
  'Maroon',
  'MediumAquamarine',
  'MediumBlue',
  'MediumOrchid',
  'MediumPurple',
  'MediumSeaGreen',
  'MediumSlateBlue',
  'MediumSpringGreen',
  'MediumTurquoise',
  'MediumVioletRed',
  'MidnightBlue',
  'MintCream',
  'MistyRose',
  'Moccasin',
  'NavajoWhite',
  'Navy',
  'NavyBlue',
  'OldLace',
  'Olive',
  'OliveDrab',
  'Orange',
  'OrangeRed',
  'Orchid',
  'PaleGoldenrod',
  'PaleGreen',
  'PaleTurquoise',
  'PaleVioletRed',
  'PapayaWhip',
  'PeachPuff',
  'Peru',
  'Pink',
  'Plum',
  'PowderBlue',
  'Purple',
  'Red',
  'RosyBrown',
  'RoyalBlue',
  'SaddleBrown',
  'Salmon',
  'SandyBrown',
  'SeaGreen',
  'Seashell',
  'Sienna',
  'Silver',
  'SkyBlue',
  'SlateBlue',
  'SlateGray',
  'SlateGrey',
  'Snow',
  'SpringGreen',
  'SteelBlue',
  'Tan',
  'Teal',
  'Thistle',
  'Tomato',
  'Turquoise',
  'Violet',
  'VioletRed',
  'Wheat',
  'White',
  'WhiteSmoke',
  'Yellow',
  'YellowGreen']
  rgb=[
  [0.000000,1.000000,1.000000],
  [0.498000,1.000000,0.830000],
  [0.940000,1.000000,1.000000],
  [0.960000,0.960000,0.864000],
  [1.000000,0.894000,0.770000],
  [0.000000,0.000000,0.000000],
  [1.000000,0.920000,0.804000],
  [0.000000,0.000000,1.000000],
  [0.540000,0.170000,0.888000],
  [0.648000,0.165000,0.165000],
  [0.870000,0.720000,0.530000],
  [0.372000,0.620000,0.628000],
  [0.498000,1.000000,0.000000],
  [0.824000,0.410000,0.116000],
  [1.000000,0.498000,0.312000],
  [0.392000,0.585000,0.930000],
  [1.000000,0.972000,0.864000],
  [0.864000,0.080000,0.235000],
  [0.000000,1.000000,1.000000],
  [0.000000,0.000000,0.545000],
  [0.000000,0.545000,0.545000],
  [0.720000,0.525000,0.044000],
  [0.664000,0.664000,0.664000],
  [0.000000,0.392000,0.000000],
  [0.664000,0.664000,0.664000],
  [0.740000,0.716000,0.420000],
  [0.545000,0.000000,0.545000],
  [0.332000,0.420000,0.185000],
  [1.000000,0.550000,0.000000],
  [0.600000,0.196000,0.800000],
  [0.545000,0.000000,0.000000],
  [0.912000,0.590000,0.480000],
  [0.560000,0.736000,0.560000],
  [0.284000,0.240000,0.545000],
  [0.185000,0.310000,0.310000],
  [0.185000,0.310000,0.310000],
  [0.000000,0.808000,0.820000],
  [0.580000,0.000000,0.828000],
  [1.000000,0.080000,0.576000],
  [0.000000,0.750000,1.000000],
  [0.410000,0.410000,0.410000],
  [0.410000,0.410000,0.410000],
  [0.116000,0.565000,1.000000],
  [0.698000,0.132000,0.132000],
  [1.000000,0.980000,0.940000],
  [0.132000,0.545000,0.132000],
  [1.000000,0.000000,1.000000],
  [0.864000,0.864000,0.864000],
  [0.972000,0.972000,1.000000],
  [1.000000,0.844000,0.000000],
  [0.855000,0.648000,0.125000],
  [0.500000,0.500000,0.500000],
  [0.000000,0.500000,0.000000],
  [0.680000,1.000000,0.185000],
  [0.500000,0.500000,0.500000],
  [0.940000,1.000000,0.940000],
  [1.000000,0.410000,0.705000],
  [0.804000,0.360000,0.360000],
  [0.294000,0.000000,0.510000],
  [1.000000,1.000000,0.940000],
  [0.940000,0.900000,0.550000],
  [0.900000,0.900000,0.980000],
  [1.000000,0.940000,0.960000],
  [0.488000,0.990000,0.000000],
  [1.000000,0.980000,0.804000],
  [0.680000,0.848000,0.900000],
  [0.940000,0.500000,0.500000],
  [0.880000,1.000000,1.000000],
  [0.933000,0.867000,0.510000],
  [0.980000,0.980000,0.824000],
  [0.828000,0.828000,0.828000],
  [0.565000,0.932000,0.565000],
  [0.828000,0.828000,0.828000],
  [1.000000,0.712000,0.756000],
  [1.000000,0.628000,0.480000],
  [0.125000,0.698000,0.668000],
  [0.530000,0.808000,0.980000],
  [0.518000,0.440000,1.000000],
  [0.468000,0.532000,0.600000],
  [0.468000,0.532000,0.600000],
  [0.690000,0.770000,0.870000],
  [1.000000,1.000000,0.880000],
  [0.000000,1.000000,0.000000],
  [0.196000,0.804000,0.196000],
  [0.980000,0.940000,0.900000],
  [1.000000,0.000000,1.000000],
  [0.500000,0.000000,0.000000],
  [0.400000,0.804000,0.668000],
  [0.000000,0.000000,0.804000],
  [0.730000,0.332000,0.828000],
  [0.576000,0.440000,0.860000],
  [0.235000,0.700000,0.444000],
  [0.484000,0.408000,0.932000],
  [0.000000,0.980000,0.604000],
  [0.284000,0.820000,0.800000],
  [0.780000,0.084000,0.520000],
  [0.098000,0.098000,0.440000],
  [0.960000,1.000000,0.980000],
  [1.000000,0.894000,0.884000],
  [1.000000,0.894000,0.710000],
  [1.000000,0.870000,0.680000],
  [0.000000,0.000000,0.500000],
  [0.000000,0.000000,0.500000],
  [0.992000,0.960000,0.900000],
  [0.500000,0.500000,0.000000],
  [0.420000,0.556000,0.136000],
  [1.000000,0.648000,0.000000],
  [1.000000,0.270000,0.000000],
  [0.855000,0.440000,0.840000],
  [0.932000,0.910000,0.668000],
  [0.596000,0.985000,0.596000],
  [0.688000,0.932000,0.932000],
  [0.860000,0.440000,0.576000],
  [1.000000,0.936000,0.835000],
  [1.000000,0.855000,0.725000],
  [0.804000,0.520000,0.248000],
  [1.000000,0.752000,0.796000],
  [0.868000,0.628000,0.868000],
  [0.690000,0.880000,0.900000],
  [0.500000,0.000000,0.500000],
  [1.000000,0.000000,0.000000],
  [0.736000,0.560000,0.560000],
  [0.255000,0.410000,0.884000],
  [0.545000,0.270000,0.075000],
  [0.980000,0.500000,0.448000],
  [0.956000,0.644000,0.376000],
  [0.180000,0.545000,0.340000],
  [1.000000,0.960000,0.932000],
  [0.628000,0.320000,0.176000],
  [0.752000,0.752000,0.752000],
  [0.530000,0.808000,0.920000],
  [0.415000,0.352000,0.804000],
  [0.440000,0.500000,0.565000],
  [0.440000,0.500000,0.565000],
  [1.000000,0.980000,0.980000],
  [0.000000,1.000000,0.498000],
  [0.275000,0.510000,0.705000],
  [0.824000,0.705000,0.550000],
  [0.000000,0.500000,0.500000],
  [0.848000,0.750000,0.848000],
  [1.000000,0.390000,0.280000],
  [0.250000,0.880000,0.815000],
  [0.932000,0.510000,0.932000],
  [0.816000,0.125000,0.565000],
  [0.960000,0.870000,0.700000],
  [1.000000,1.000000,1.000000],
  [0.960000,0.960000,0.960000],
  [1.000000,1.000000,0.000000],
  [0.604000,0.804000,0.196000]]
  name=[x.lower() for x in name]
  return dict(zip(name,rgb))
